@@ -207,6 +207,8 @@ static const struct link_mode_info link_modes[] = {
 		{ LM_CLASS_REAL,	400000,	DUPLEX_FULL },
 	[ETHTOOL_LINK_MODE_400000baseCR8_Full_BIT] =
 		{ LM_CLASS_REAL,	400000,	DUPLEX_FULL },
+	[ETHTOOL_LINK_MODE_FEC_LLRS_BIT] =
+		{ LM_CLASS_FEC },
 };
 const unsigned int link_modes_count = ARRAY_SIZE(link_modes);
 
@@ -375,7 +377,7 @@ static int dump_link_modes(struct nl_context *nlctx,
 after:
 	if (first && if_none)
 		printf("%s", if_none);
-	printf(after);
+	printf("%s", after);
 
 	return 0;
 err:
@@ -726,6 +728,13 @@ int nl_gset(struct cmd_context *ctx)
 	struct nl_socket *nlsk = nlctx->ethnl_socket;
 	int ret;
 
+	if (netlink_cmd_check(ctx, ETHTOOL_MSG_LINKMODES_GET, true) ||
+	    netlink_cmd_check(ctx, ETHTOOL_MSG_LINKINFO_GET, true) ||
+	    netlink_cmd_check(ctx, ETHTOOL_MSG_WOL_GET, true) ||
+	    netlink_cmd_check(ctx, ETHTOOL_MSG_DEBUG_GET, true) ||
+	    netlink_cmd_check(ctx, ETHTOOL_MSG_LINKSTATE_GET, true))
+		return -EOPNOTSUPP;
+
 	nlctx->suppress_nlerr = 1;
 
 	ret = gset_request(nlsk, ETHTOOL_MSG_LINKMODES_GET,
